"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deploy = void 0;
const scrapbox_client_1 = require("../../scrapbox-client");
const rest_api_client_1 = require("../../scrapbox-client/rest-api-client/rest-api-client");
const websocket_client_1 = require("../../scrapbox-client/websocket-clinet/websocket-client");
const file_loaders_1 = require("../internal/file-loaders");
const find_1 = require("../internal/find");
const util_1 = require("../internal/util");
const deploy = async ({ page, sourceFilePath, project, token }) => {
    const errors = util_1.validateDeployArguments({ token, sourceFilePath, project, page });
    if (errors.length) {
        throw new Error(`ParameterError: ${JSON.stringify(errors)}`);
    }
    const codeBlockLabel = util_1.isCSSFile(sourceFilePath) ? 'style.css' : 'script.js';
    const apiClient = new rest_api_client_1.RestApiClient(token);
    const [user, projectData] = await Promise.all([apiClient.getMe(), apiClient.getProject(project)]);
    const scrapboxClient = new scrapbox_client_1.ScrapboxClient(user, projectData, new rest_api_client_1.RestApiClient(token), new websocket_client_1.WebsocketClient({ token }));
    const sourceCode = await file_loaders_1.loadSourceCode(sourceFilePath);
    const pageData = await scrapboxClient.getPage(page);
    // NOTE: assuming code-block exists already
    const lineId = find_1.findNextLineIdOrFail(codeBlockLabel, pageData.lines);
    // FIXME: bad type assertion
    await scrapboxClient.changeLine(page, { type: 'update', id: lineId, text: sourceCode });
};
exports.deploy = deploy;
//# sourceMappingURL=deploy.js.map