"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScrapboxClient = void 0;
class ScrapboxClient {
    constructor(user, project, apiClient, websocketClient) {
        this.user = user;
        this.project = project;
        this.apiClient = apiClient;
        this.websocketClient = websocketClient;
    }
    getCurrentUser() {
        return { ...this.user };
    }
    getCurrentProject() {
        return { ...this.project };
    }
    async getPage(pageName) {
        return this.apiClient.getPage(this.project.name, pageName);
    }
    async changeLine(pageName, change) {
        const { pageId, commitId } = await this.getPageIdAndCommitId(pageName);
        return this.commit({
            changes: Array.isArray(change) ? change : [change],
            projectId: this.project.id,
            pageId: pageId,
            commitId: commitId,
        });
    }
    async getPageIdAndCommitId(pageName) {
        const page = await this.apiClient.getPage(this.project.name, pageName);
        return { pageId: page.id, commitId: page.commitId };
    }
    async commit(param) {
        // to receive result of commit
        await this.websocketClient.join({ projectId: param.projectId, pageId: param.pageId });
        return this.websocketClient.commit({
            userId: this.user.id,
            projectId: param.projectId,
            pageId: param.pageId,
            parentId: param.commitId,
            changes: param.changes,
        });
    }
}
exports.ScrapboxClient = ScrapboxClient;
//# sourceMappingURL=scrapbox-client.js.map